-- ----------------------------
-- 设备生产厂商表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_firm`;
CREATE TABLE mortals_xhx_firm(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '主键ID，主键，自增长',
    `firmName` varchar(128) NOT NULL    COMMENT '设备生产厂商名称',
    `firmCode` varchar(128)     COMMENT '设备生产商编码',
    `firmRemark` varchar(64)     COMMENT '备注',
    `createUserId` bigint(20) NOT NULL    COMMENT '创建用户',
    `createTime` datetime NOT NULL    COMMENT '创建时间',
    `updateUserId` bigint(20)     COMMENT '更新用户',
    `updateTime` datetime     COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='设备生产厂商';
-- ----------------------------
-- 设备表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_device`;
CREATE TABLE mortals_xhx_device(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '主键ID，主键，自增长',
    `deviceName` varchar(20) NOT NULL    COMMENT '设备名称',
    `deviceCode` varchar(256)     COMMENT '设备编码',
    `siteCode` varchar(256)     COMMENT '站点编号，来源基础服务平台',
    `siteName` varchar(256)     COMMENT '站点名称',
    `deviceMac` varchar(64)     COMMENT '设备的MAC地址',
    `platformId` bigint(20) NOT NULL    COMMENT '平台系统Id',
    `platformName` varchar(256) NOT NULL    COMMENT '平台系统名称',
    `productId` bigint(20) NOT NULL    COMMENT '产品Id',
    `productName` varchar(256) NOT NULL    COMMENT '产品名称',
    `deviceFirmId` bigint(20)     COMMENT '设备生产厂商ID',
    `deviceFirmname` varchar(20)     COMMENT '设备生产厂商名称',
    `ip` varchar(64)     COMMENT '设备访问ip',
    `centernum` varchar(64)     COMMENT '中心设备编码',
    `port` varchar(64)     COMMENT '端口',
    `deviceOnlineStatus` tinyint(2) NOT NULL    COMMENT '在线状态 (0.离线，1.在线)',
    `status` tinyint(2) NOT NULL    COMMENT '启用状态 (0.停止，1.启用)',
    `active` tinyint(2) NOT NULL    COMMENT '激活状态 (0.未激活，1.已激活)',
    `deviceRemark` varchar(256)     COMMENT '备注',
    `onlineTime` datetime     COMMENT '最近上线时间',
    `offlineTime` datetime     COMMENT '最近离线时间',
    `createUserId` bigint(20) NOT NULL    COMMENT '创建用户',
    `createTime` datetime NOT NULL    COMMENT '创建时间',
    `updateUserId` bigint(20)     COMMENT '更新用户',
    `updateTime` datetime     COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='设备';

-- ----------------------------
-- 平台系统表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_platform`;
CREATE TABLE mortals_xhx_platform(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '主键ID，主键，自增长',
    `platformName` varchar(20) NOT NULL    COMMENT '平台名称，名称唯一',
    `platformSn` varchar(256) NOT NULL    COMMENT '平台编码，编码唯一(编码加上站点编码，如phxt-51010251-1做Vhost虚拟机编码)',
    `sendMsgType` tinyint(2) NOT NULL    COMMENT '发送第三方平台消息类型(0.http,1.jms)',
    `sendConfig` varchar(2048)     COMMENT '发送参数配置，如发送消息地址等，xml结构,根据消息类型变化',
    `sendSwitch` tinyint(2) NOT NULL    COMMENT '是否启用发送消息(0.停用,1.启用)',
    `platformRemark` varchar(256)     COMMENT '备注',
    `createUserId` bigint(20) NOT NULL    COMMENT '创建用户',
    `createTime` datetime NOT NULL    COMMENT '创建时间',
    `updateUserId` bigint(20)     COMMENT '更新用户',
    `updateTime` datetime     COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='平台系统';
-- ----------------------------
-- 产品表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_product`;
CREATE TABLE mortals_xhx_product(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '主键ID，主键，自增长',
    `productName` varchar(20) NOT NULL    COMMENT '产品名称，名称唯一',
    `productCode` varchar(256) NOT NULL    COMMENT '产品编码，编码唯一',
    `exchangeName` varchar(256) NOT NULL    COMMENT '交换机名称,英文必填，默认产品编码',
    `productRemark` varchar(256)     COMMENT '备注',
    `createUserId` bigint(20) NOT NULL    COMMENT '创建用户',
    `createTime` datetime NOT NULL    COMMENT '创建时间',
    `updateUserId` bigint(20)     COMMENT '更新用户',
    `updateTime` datetime     COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='产品';
-- ----------------------------
-- 设备日志表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_device_log`;
CREATE TABLE mortals_xhx_device_log(
    `id` bigint(20)   AUTO_INCREMENT  COMMENT '主键ID，主键，自增长',
    `deviceId` bigint(20)     COMMENT '设备ID',
    `deviceNum` varchar(32) NOT NULL    COMMENT '设备编号',
    `deviceName` varchar(32) NOT NULL    COMMENT '设备名称，设置设备名称。',
    `logType` tinyint(2) NOT NULL    COMMENT '日志类型，(0.上报事件，1.下发服务)',
    `content` varchar(2048)     COMMENT '内容',
    `createUserId` bigint(20) NOT NULL    COMMENT '创建用户',
    `createTime` datetime NOT NULL    COMMENT '创建时间',
    `updateUserId` bigint(20)     COMMENT '更新用户',
    `updateTime` datetime     COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='设备日志';
